@@ -5,6 +5,7 @@
 */
 
 #include <QPluginLoader>
+#include <optional>
 
 namespace KStaticPluginHelpers
 {
@@ -12,5 +13,7 @@ namespace KStaticPluginHelpers
  * This is an implementations detail since consumers should only interact with KPluginMetaData::findPlugin*
  * to query the available plugins!
  */
-QList<QStaticPlugin> staticPlugins(const QString &directory);
+std::optional<QStaticPlugin> findById(const QString &directory, const QString &pluginId);
+/// Map of pluginId and actual plugin
+QMap<QString, QStaticPlugin> staticPlugins(const QString &directory);
 }
